@@ -181,8 +181,10 @@ write_playlist (TotemBemusedPlugin *tp, GIOChannel *source)
 		char *title;
 
 		title = totem_get_title_at_playlist_pos (tp->totem, i);
-		if (title == NULL)
+		if (title == NULL) {
+			/* Translators: the parameter is a number used to identify this playlist entry */
 			title = g_strdup_printf (_("Untitled %d"), i);
+		}
 		g_message ("pushing entry %s", title);
 		send_response_flush (tp, source, title, strlen (title), FALSE);
 		g_free (title);
@@ -251,7 +253,7 @@ seek_to_pos (TotemBemusedPlugin *tp, GIOChannel *source)
 	time += buf[2] << 8;
 	time += buf[3];
 
-	totem_action_seek_time (tp->totem, (gint64) time * 1000);
+	totem_action_seek_time (tp->totem, (gint64) time * 1000, FALSE);
 }
 
 static void
